#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-handle
version:              0.1.0.6
visibility:           public
id:                   bytestring-handle-0.1.0.6-54FhKAwuvx4IQrk7FYHtBV
key:                  bytestring-handle-0.1.0.6-54FhKAwuvx4IQrk7FYHtBV
license:              BSD-3-Clause
maintainer:           Ganesh Sittampalam <ganesh@earth.li>
author:               Ganesh Sittampalam
homepage:             http://hub.darcs.net/ganesh/bytestring-handle
synopsis:             ByteString-backed Handles
category:             System
abi:                  e26fc2baf2411d115b123682b4c945c0
exposed:              True
exposed-modules:      Data.ByteString.Handle
hidden-modules:
    Data.ByteString.Handle.Read Data.ByteString.Handle.Write

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bytestring-handle-0.1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bytestring-handle-0.1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bytestring-handle-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-handle
hs-libraries:         HSbytestring-handle-0.1.0.6-54FhKAwuvx4IQrk7FYHtBV
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-handle/html/bytestring-handle.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-handle/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

